SystemOrganization addCategory: 'ConfigurationOfShout'!

Object subclass: #ConfigurationOfShout
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfShout'!

!ConfigurationOfShout class methodsFor: 'private' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfShout class methodsFor: 'private' stamp: 'DaleHenrichs 12/29/2009 17:58'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfShout class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfShout class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfShout class methodsFor: 'metacello tool support' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfShout class methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
project

	^self new project! !

!ConfigurationOfShout methodsFor: 'baselines' stamp: 'dkh 1/12/2010 11:17'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/shout'.
		spec 
			package: 'Shout';
			package: 'ShoutWorkspace.1';
			package: 'ShoutTests' with: [ spec requires: 'Shout' ].
			
		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #( 'Shout' 'ShoutWorkspace.1' );
			group: 'Tests' with: #('ShoutTests' );
			group: 'Core Tests' with: #('Core' 'Tests' );
			
			yourself.	
			
	].
	spec for: #squeak do: [
		spec repository: 'http://source.squeak.org/trunk'.

		spec package: 'ShoutCore'.

		spec
			group: 'default' with: #('Core' );
			group: 'Core' with: #( 'ShoutCore'  );
			group: 'Tests' with: #('Core');
			group: 'Core Tests' with: #('Core' 'Tests' );
			
			yourself.	
	].! !

!ConfigurationOfShout methodsFor: 'accessing' stamp: 'MarianoMartinezPeck 12/18/2009 15:16'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfShout methodsFor: 'versions' stamp: 'dkh 1/12/2010 11:22'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'MarianoMartinezPeck'.
		spec description: 'First release 1.0 of this project '.
	].
	
	spec for: #pharo do: [		
		spec 
			package: 'Shout' with: 'Shout-nice.83';
			package: 'ShoutWorkspace.1' with: 'ShoutWorkspace.1-tween.4';
			package: 'ShoutTests' with: 'ShoutTests-tween.9'.
				
	].
	spec for: #squeak do: [
		spec author: 'DaleHenrichs'.
		spec description: 'Squeak support based on Squeak3.10.2-Trunk-090912 and OmniBrowser-2.0.3.sar'.
		spec package: 'ShoutCore' with: 'ShoutCore-nice.7'.
	].! !

!ConfigurationOfShout methodsFor: 'versions' stamp: 'DaleHenrichs 07/26/2010 20:42'!
version111: spec
	<version: '1.1.1' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #release.
		spec author: 'DaleHenrichs'.
		spec description: 'Ported ShoutCore to GemStone (removed Preferences ref)'.
	].
	
	spec for: #pharo do: [		
		spec 
			package: 'Shout' with: 'Shout-nice.83';
			package: 'ShoutWorkspace.1' with: 'ShoutWorkspace.1-tween.4';
			package: 'ShoutTests' with: 'ShoutTests-tween.9'.
				
	].
	spec for: #squeak do: [
		spec author: 'DaleHenrichs'.
		spec description: 'Squeak support based on Squeak3.10.2-Trunk-090912 and OmniBrowser-2.0.3.sar'.
		spec package: 'ShoutCore' with: 'ShoutCore-nice.7'.
	].		
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/shout'.	
		spec package: 'ShoutCore' with: 'ShoutCore-DaleHenrichs.8'. 
	].! !

!ConfigurationOfShout methodsFor: 'versions' stamp: 'MarianoMartinezPeck 7/17/2010 13:10'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline')>

	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Alexandre Bergel'.
		spec description: 'On the way for 1.1'.
	].
	
	spec for: #pharo do: [		
		spec 
			package: 'Shout' with: 'Shout-lr.84';
			package: 'ShoutWorkspace.1' with: 'ShoutWorkspace.1-maiano.6';
			package: 'ShoutTests' with: 'ShoutTests-MarianoMartinezPeck.10'.
				
	].
	spec for: #squeak do: [
		spec author: 'DaleHenrichs'.
		spec description: 'Squeak support based on Squeak3.10.2-Trunk-090912 and OmniBrowser-2.0.3.sar'.
		spec package: 'ShoutCore' with: 'ShoutCore-nice.7'.
	].! !
